// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/clients/client.proto

package ubii.clients;

public final class ClientOuterClass {
  private ClientOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface ClientOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.clients.Client)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string id = 1;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 1;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>string name = 2;</code>
     */
    java.lang.String getName();
    /**
     * <code>string name = 2;</code>
     */
    com.google.protobuf.ByteString
        getNameBytes();

    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    java.util.List<ubii.devices.DeviceOuterClass.Device> 
        getDevicesList();
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    ubii.devices.DeviceOuterClass.Device getDevices(int index);
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    int getDevicesCount();
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    java.util.List<? extends ubii.devices.DeviceOuterClass.DeviceOrBuilder> 
        getDevicesOrBuilderList();
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    ubii.devices.DeviceOuterClass.DeviceOrBuilder getDevicesOrBuilder(
        int index);

    /**
     * <code>repeated string tags = 4;</code>
     */
    java.util.List<java.lang.String>
        getTagsList();
    /**
     * <code>repeated string tags = 4;</code>
     */
    int getTagsCount();
    /**
     * <code>repeated string tags = 4;</code>
     */
    java.lang.String getTags(int index);
    /**
     * <code>repeated string tags = 4;</code>
     */
    com.google.protobuf.ByteString
        getTagsBytes(int index);

    /**
     * <code>string description = 5;</code>
     */
    java.lang.String getDescription();
    /**
     * <code>string description = 5;</code>
     */
    com.google.protobuf.ByteString
        getDescriptionBytes();

    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> 
        getProcessingModulesList();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index);
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    int getProcessingModulesCount();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
        getProcessingModulesOrBuilderList();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
        int index);

    /**
     * <code>bool is_dedicated_processing_node = 7;</code>
     */
    boolean getIsDedicatedProcessingNode();

    /**
     * <code>string host_ip = 8;</code>
     */
    java.lang.String getHostIp();
    /**
     * <code>string host_ip = 8;</code>
     */
    com.google.protobuf.ByteString
        getHostIpBytes();

    /**
     * <code>string metadata_json = 9;</code>
     */
    java.lang.String getMetadataJson();
    /**
     * <code>string metadata_json = 9;</code>
     */
    com.google.protobuf.ByteString
        getMetadataJsonBytes();

    /**
     * <code>.ubii.clients.Client.State state = 10;</code>
     */
    int getStateValue();
    /**
     * <code>.ubii.clients.Client.State state = 10;</code>
     */
    ubii.clients.ClientOuterClass.Client.State getState();

    /**
     * <code>float latency = 11;</code>
     */
    float getLatency();
  }
  /**
   * Protobuf type {@code ubii.clients.Client}
   */
  public  static final class Client extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.clients.Client)
      ClientOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Client.newBuilder() to construct.
    private Client(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Client() {
      id_ = "";
      name_ = "";
      devices_ = java.util.Collections.emptyList();
      tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      description_ = "";
      processingModules_ = java.util.Collections.emptyList();
      isDedicatedProcessingNode_ = false;
      hostIp_ = "";
      metadataJson_ = "";
      state_ = 0;
      latency_ = 0F;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Client(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();

              name_ = s;
              break;
            }
            case 26: {
              if (!((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
                devices_ = new java.util.ArrayList<ubii.devices.DeviceOuterClass.Device>();
                mutable_bitField0_ |= 0x00000004;
              }
              devices_.add(
                  input.readMessage(ubii.devices.DeviceOuterClass.Device.parser(), extensionRegistry));
              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
                tags_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000008;
              }
              tags_.add(s);
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();

              description_ = s;
              break;
            }
            case 50: {
              if (!((mutable_bitField0_ & 0x00000020) == 0x00000020)) {
                processingModules_ = new java.util.ArrayList<ubii.processing.ProcessingModuleOuterClass.ProcessingModule>();
                mutable_bitField0_ |= 0x00000020;
              }
              processingModules_.add(
                  input.readMessage(ubii.processing.ProcessingModuleOuterClass.ProcessingModule.parser(), extensionRegistry));
              break;
            }
            case 56: {

              isDedicatedProcessingNode_ = input.readBool();
              break;
            }
            case 66: {
              java.lang.String s = input.readStringRequireUtf8();

              hostIp_ = s;
              break;
            }
            case 74: {
              java.lang.String s = input.readStringRequireUtf8();

              metadataJson_ = s;
              break;
            }
            case 80: {
              int rawValue = input.readEnum();

              state_ = rawValue;
              break;
            }
            case 93: {

              latency_ = input.readFloat();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
          devices_ = java.util.Collections.unmodifiableList(devices_);
        }
        if (((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
          tags_ = tags_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000020) == 0x00000020)) {
          processingModules_ = java.util.Collections.unmodifiableList(processingModules_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.clients.ClientOuterClass.internal_static_ubii_clients_Client_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.clients.ClientOuterClass.internal_static_ubii_clients_Client_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.clients.ClientOuterClass.Client.class, ubii.clients.ClientOuterClass.Client.Builder.class);
    }

    /**
     * Protobuf enum {@code ubii.clients.Client.State}
     */
    public enum State
        implements com.google.protobuf.ProtocolMessageEnum {
      /**
       * <code>ACTIVE = 0;</code>
       */
      ACTIVE(0),
      /**
       * <code>INACTIVE = 1;</code>
       */
      INACTIVE(1),
      /**
       * <code>UNAVAILABLE = 2;</code>
       */
      UNAVAILABLE(2),
      UNRECOGNIZED(-1),
      ;

      /**
       * <code>ACTIVE = 0;</code>
       */
      public static final int ACTIVE_VALUE = 0;
      /**
       * <code>INACTIVE = 1;</code>
       */
      public static final int INACTIVE_VALUE = 1;
      /**
       * <code>UNAVAILABLE = 2;</code>
       */
      public static final int UNAVAILABLE_VALUE = 2;


      public final int getNumber() {
        if (this == UNRECOGNIZED) {
          throw new java.lang.IllegalArgumentException(
              "Can't get the number of an unknown enum value.");
        }
        return value;
      }

      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static State valueOf(int value) {
        return forNumber(value);
      }

      public static State forNumber(int value) {
        switch (value) {
          case 0: return ACTIVE;
          case 1: return INACTIVE;
          case 2: return UNAVAILABLE;
          default: return null;
        }
      }

      public static com.google.protobuf.Internal.EnumLiteMap<State>
          internalGetValueMap() {
        return internalValueMap;
      }
      private static final com.google.protobuf.Internal.EnumLiteMap<
          State> internalValueMap =
            new com.google.protobuf.Internal.EnumLiteMap<State>() {
              public State findValueByNumber(int number) {
                return State.forNumber(number);
              }
            };

      public final com.google.protobuf.Descriptors.EnumValueDescriptor
          getValueDescriptor() {
        return getDescriptor().getValues().get(ordinal());
      }
      public final com.google.protobuf.Descriptors.EnumDescriptor
          getDescriptorForType() {
        return getDescriptor();
      }
      public static final com.google.protobuf.Descriptors.EnumDescriptor
          getDescriptor() {
        return ubii.clients.ClientOuterClass.Client.getDescriptor().getEnumTypes().get(0);
      }

      private static final State[] VALUES = values();

      public static State valueOf(
          com.google.protobuf.Descriptors.EnumValueDescriptor desc) {
        if (desc.getType() != getDescriptor()) {
          throw new java.lang.IllegalArgumentException(
            "EnumValueDescriptor is not for this type.");
        }
        if (desc.getIndex() == -1) {
          return UNRECOGNIZED;
        }
        return VALUES[desc.getIndex()];
      }

      private final int value;

      private State(int value) {
        this.value = value;
      }

      // @@protoc_insertion_point(enum_scope:ubii.clients.Client.State)
    }

    private int bitField0_;
    public static final int ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 1;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int NAME_FIELD_NUMBER = 2;
    private volatile java.lang.Object name_;
    /**
     * <code>string name = 2;</code>
     */
    public java.lang.String getName() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        name_ = s;
        return s;
      }
    }
    /**
     * <code>string name = 2;</code>
     */
    public com.google.protobuf.ByteString
        getNameBytes() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        name_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int DEVICES_FIELD_NUMBER = 3;
    private java.util.List<ubii.devices.DeviceOuterClass.Device> devices_;
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    public java.util.List<ubii.devices.DeviceOuterClass.Device> getDevicesList() {
      return devices_;
    }
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    public java.util.List<? extends ubii.devices.DeviceOuterClass.DeviceOrBuilder> 
        getDevicesOrBuilderList() {
      return devices_;
    }
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    public int getDevicesCount() {
      return devices_.size();
    }
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    public ubii.devices.DeviceOuterClass.Device getDevices(int index) {
      return devices_.get(index);
    }
    /**
     * <code>repeated .ubii.devices.Device devices = 3;</code>
     */
    public ubii.devices.DeviceOuterClass.DeviceOrBuilder getDevicesOrBuilder(
        int index) {
      return devices_.get(index);
    }

    public static final int TAGS_FIELD_NUMBER = 4;
    private com.google.protobuf.LazyStringList tags_;
    /**
     * <code>repeated string tags = 4;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getTagsList() {
      return tags_;
    }
    /**
     * <code>repeated string tags = 4;</code>
     */
    public int getTagsCount() {
      return tags_.size();
    }
    /**
     * <code>repeated string tags = 4;</code>
     */
    public java.lang.String getTags(int index) {
      return tags_.get(index);
    }
    /**
     * <code>repeated string tags = 4;</code>
     */
    public com.google.protobuf.ByteString
        getTagsBytes(int index) {
      return tags_.getByteString(index);
    }

    public static final int DESCRIPTION_FIELD_NUMBER = 5;
    private volatile java.lang.Object description_;
    /**
     * <code>string description = 5;</code>
     */
    public java.lang.String getDescription() {
      java.lang.Object ref = description_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        description_ = s;
        return s;
      }
    }
    /**
     * <code>string description = 5;</code>
     */
    public com.google.protobuf.ByteString
        getDescriptionBytes() {
      java.lang.Object ref = description_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        description_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PROCESSING_MODULES_FIELD_NUMBER = 6;
    private java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> processingModules_;
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> getProcessingModulesList() {
      return processingModules_;
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    public java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
        getProcessingModulesOrBuilderList() {
      return processingModules_;
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    public int getProcessingModulesCount() {
      return processingModules_.size();
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index) {
      return processingModules_.get(index);
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
        int index) {
      return processingModules_.get(index);
    }

    public static final int IS_DEDICATED_PROCESSING_NODE_FIELD_NUMBER = 7;
    private boolean isDedicatedProcessingNode_;
    /**
     * <code>bool is_dedicated_processing_node = 7;</code>
     */
    public boolean getIsDedicatedProcessingNode() {
      return isDedicatedProcessingNode_;
    }

    public static final int HOST_IP_FIELD_NUMBER = 8;
    private volatile java.lang.Object hostIp_;
    /**
     * <code>string host_ip = 8;</code>
     */
    public java.lang.String getHostIp() {
      java.lang.Object ref = hostIp_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        hostIp_ = s;
        return s;
      }
    }
    /**
     * <code>string host_ip = 8;</code>
     */
    public com.google.protobuf.ByteString
        getHostIpBytes() {
      java.lang.Object ref = hostIp_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        hostIp_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int METADATA_JSON_FIELD_NUMBER = 9;
    private volatile java.lang.Object metadataJson_;
    /**
     * <code>string metadata_json = 9;</code>
     */
    public java.lang.String getMetadataJson() {
      java.lang.Object ref = metadataJson_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        metadataJson_ = s;
        return s;
      }
    }
    /**
     * <code>string metadata_json = 9;</code>
     */
    public com.google.protobuf.ByteString
        getMetadataJsonBytes() {
      java.lang.Object ref = metadataJson_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        metadataJson_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int STATE_FIELD_NUMBER = 10;
    private int state_;
    /**
     * <code>.ubii.clients.Client.State state = 10;</code>
     */
    public int getStateValue() {
      return state_;
    }
    /**
     * <code>.ubii.clients.Client.State state = 10;</code>
     */
    public ubii.clients.ClientOuterClass.Client.State getState() {
      @SuppressWarnings("deprecation")
      ubii.clients.ClientOuterClass.Client.State result = ubii.clients.ClientOuterClass.Client.State.valueOf(state_);
      return result == null ? ubii.clients.ClientOuterClass.Client.State.UNRECOGNIZED : result;
    }

    public static final int LATENCY_FIELD_NUMBER = 11;
    private float latency_;
    /**
     * <code>float latency = 11;</code>
     */
    public float getLatency() {
      return latency_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, name_);
      }
      for (int i = 0; i < devices_.size(); i++) {
        output.writeMessage(3, devices_.get(i));
      }
      for (int i = 0; i < tags_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, tags_.getRaw(i));
      }
      if (!getDescriptionBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, description_);
      }
      for (int i = 0; i < processingModules_.size(); i++) {
        output.writeMessage(6, processingModules_.get(i));
      }
      if (isDedicatedProcessingNode_ != false) {
        output.writeBool(7, isDedicatedProcessingNode_);
      }
      if (!getHostIpBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 8, hostIp_);
      }
      if (!getMetadataJsonBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 9, metadataJson_);
      }
      if (state_ != ubii.clients.ClientOuterClass.Client.State.ACTIVE.getNumber()) {
        output.writeEnum(10, state_);
      }
      if (latency_ != 0F) {
        output.writeFloat(11, latency_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, name_);
      }
      for (int i = 0; i < devices_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, devices_.get(i));
      }
      {
        int dataSize = 0;
        for (int i = 0; i < tags_.size(); i++) {
          dataSize += computeStringSizeNoTag(tags_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getTagsList().size();
      }
      if (!getDescriptionBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(5, description_);
      }
      for (int i = 0; i < processingModules_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(6, processingModules_.get(i));
      }
      if (isDedicatedProcessingNode_ != false) {
        size += com.google.protobuf.CodedOutputStream
          .computeBoolSize(7, isDedicatedProcessingNode_);
      }
      if (!getHostIpBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(8, hostIp_);
      }
      if (!getMetadataJsonBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(9, metadataJson_);
      }
      if (state_ != ubii.clients.ClientOuterClass.Client.State.ACTIVE.getNumber()) {
        size += com.google.protobuf.CodedOutputStream
          .computeEnumSize(10, state_);
      }
      if (latency_ != 0F) {
        size += com.google.protobuf.CodedOutputStream
          .computeFloatSize(11, latency_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.clients.ClientOuterClass.Client)) {
        return super.equals(obj);
      }
      ubii.clients.ClientOuterClass.Client other = (ubii.clients.ClientOuterClass.Client) obj;

      boolean result = true;
      result = result && getId()
          .equals(other.getId());
      result = result && getName()
          .equals(other.getName());
      result = result && getDevicesList()
          .equals(other.getDevicesList());
      result = result && getTagsList()
          .equals(other.getTagsList());
      result = result && getDescription()
          .equals(other.getDescription());
      result = result && getProcessingModulesList()
          .equals(other.getProcessingModulesList());
      result = result && (getIsDedicatedProcessingNode()
          == other.getIsDedicatedProcessingNode());
      result = result && getHostIp()
          .equals(other.getHostIp());
      result = result && getMetadataJson()
          .equals(other.getMetadataJson());
      result = result && state_ == other.state_;
      result = result && (
          java.lang.Float.floatToIntBits(getLatency())
          == java.lang.Float.floatToIntBits(
              other.getLatency()));
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      hash = (37 * hash) + NAME_FIELD_NUMBER;
      hash = (53 * hash) + getName().hashCode();
      if (getDevicesCount() > 0) {
        hash = (37 * hash) + DEVICES_FIELD_NUMBER;
        hash = (53 * hash) + getDevicesList().hashCode();
      }
      if (getTagsCount() > 0) {
        hash = (37 * hash) + TAGS_FIELD_NUMBER;
        hash = (53 * hash) + getTagsList().hashCode();
      }
      hash = (37 * hash) + DESCRIPTION_FIELD_NUMBER;
      hash = (53 * hash) + getDescription().hashCode();
      if (getProcessingModulesCount() > 0) {
        hash = (37 * hash) + PROCESSING_MODULES_FIELD_NUMBER;
        hash = (53 * hash) + getProcessingModulesList().hashCode();
      }
      hash = (37 * hash) + IS_DEDICATED_PROCESSING_NODE_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashBoolean(
          getIsDedicatedProcessingNode());
      hash = (37 * hash) + HOST_IP_FIELD_NUMBER;
      hash = (53 * hash) + getHostIp().hashCode();
      hash = (37 * hash) + METADATA_JSON_FIELD_NUMBER;
      hash = (53 * hash) + getMetadataJson().hashCode();
      hash = (37 * hash) + STATE_FIELD_NUMBER;
      hash = (53 * hash) + state_;
      hash = (37 * hash) + LATENCY_FIELD_NUMBER;
      hash = (53 * hash) + java.lang.Float.floatToIntBits(
          getLatency());
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.clients.ClientOuterClass.Client parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.Client parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.Client parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.Client parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.clients.ClientOuterClass.Client prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.clients.Client}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.clients.Client)
        ubii.clients.ClientOuterClass.ClientOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_Client_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_Client_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.clients.ClientOuterClass.Client.class, ubii.clients.ClientOuterClass.Client.Builder.class);
      }

      // Construct using ubii.clients.ClientOuterClass.Client.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getDevicesFieldBuilder();
          getProcessingModulesFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        id_ = "";

        name_ = "";

        if (devicesBuilder_ == null) {
          devices_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
        } else {
          devicesBuilder_.clear();
        }
        tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000008);
        description_ = "";

        if (processingModulesBuilder_ == null) {
          processingModules_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000020);
        } else {
          processingModulesBuilder_.clear();
        }
        isDedicatedProcessingNode_ = false;

        hostIp_ = "";

        metadataJson_ = "";

        state_ = 0;

        latency_ = 0F;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_Client_descriptor;
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.Client getDefaultInstanceForType() {
        return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.Client build() {
        ubii.clients.ClientOuterClass.Client result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.Client buildPartial() {
        ubii.clients.ClientOuterClass.Client result = new ubii.clients.ClientOuterClass.Client(this);
        int from_bitField0_ = bitField0_;
        int to_bitField0_ = 0;
        result.id_ = id_;
        result.name_ = name_;
        if (devicesBuilder_ == null) {
          if (((bitField0_ & 0x00000004) == 0x00000004)) {
            devices_ = java.util.Collections.unmodifiableList(devices_);
            bitField0_ = (bitField0_ & ~0x00000004);
          }
          result.devices_ = devices_;
        } else {
          result.devices_ = devicesBuilder_.build();
        }
        if (((bitField0_ & 0x00000008) == 0x00000008)) {
          tags_ = tags_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000008);
        }
        result.tags_ = tags_;
        result.description_ = description_;
        if (processingModulesBuilder_ == null) {
          if (((bitField0_ & 0x00000020) == 0x00000020)) {
            processingModules_ = java.util.Collections.unmodifiableList(processingModules_);
            bitField0_ = (bitField0_ & ~0x00000020);
          }
          result.processingModules_ = processingModules_;
        } else {
          result.processingModules_ = processingModulesBuilder_.build();
        }
        result.isDedicatedProcessingNode_ = isDedicatedProcessingNode_;
        result.hostIp_ = hostIp_;
        result.metadataJson_ = metadataJson_;
        result.state_ = state_;
        result.latency_ = latency_;
        result.bitField0_ = to_bitField0_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.clients.ClientOuterClass.Client) {
          return mergeFrom((ubii.clients.ClientOuterClass.Client)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.clients.ClientOuterClass.Client other) {
        if (other == ubii.clients.ClientOuterClass.Client.getDefaultInstance()) return this;
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (!other.getName().isEmpty()) {
          name_ = other.name_;
          onChanged();
        }
        if (devicesBuilder_ == null) {
          if (!other.devices_.isEmpty()) {
            if (devices_.isEmpty()) {
              devices_ = other.devices_;
              bitField0_ = (bitField0_ & ~0x00000004);
            } else {
              ensureDevicesIsMutable();
              devices_.addAll(other.devices_);
            }
            onChanged();
          }
        } else {
          if (!other.devices_.isEmpty()) {
            if (devicesBuilder_.isEmpty()) {
              devicesBuilder_.dispose();
              devicesBuilder_ = null;
              devices_ = other.devices_;
              bitField0_ = (bitField0_ & ~0x00000004);
              devicesBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getDevicesFieldBuilder() : null;
            } else {
              devicesBuilder_.addAllMessages(other.devices_);
            }
          }
        }
        if (!other.tags_.isEmpty()) {
          if (tags_.isEmpty()) {
            tags_ = other.tags_;
            bitField0_ = (bitField0_ & ~0x00000008);
          } else {
            ensureTagsIsMutable();
            tags_.addAll(other.tags_);
          }
          onChanged();
        }
        if (!other.getDescription().isEmpty()) {
          description_ = other.description_;
          onChanged();
        }
        if (processingModulesBuilder_ == null) {
          if (!other.processingModules_.isEmpty()) {
            if (processingModules_.isEmpty()) {
              processingModules_ = other.processingModules_;
              bitField0_ = (bitField0_ & ~0x00000020);
            } else {
              ensureProcessingModulesIsMutable();
              processingModules_.addAll(other.processingModules_);
            }
            onChanged();
          }
        } else {
          if (!other.processingModules_.isEmpty()) {
            if (processingModulesBuilder_.isEmpty()) {
              processingModulesBuilder_.dispose();
              processingModulesBuilder_ = null;
              processingModules_ = other.processingModules_;
              bitField0_ = (bitField0_ & ~0x00000020);
              processingModulesBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getProcessingModulesFieldBuilder() : null;
            } else {
              processingModulesBuilder_.addAllMessages(other.processingModules_);
            }
          }
        }
        if (other.getIsDedicatedProcessingNode() != false) {
          setIsDedicatedProcessingNode(other.getIsDedicatedProcessingNode());
        }
        if (!other.getHostIp().isEmpty()) {
          hostIp_ = other.hostIp_;
          onChanged();
        }
        if (!other.getMetadataJson().isEmpty()) {
          metadataJson_ = other.metadataJson_;
          onChanged();
        }
        if (other.state_ != 0) {
          setStateValue(other.getStateValue());
        }
        if (other.getLatency() != 0F) {
          setLatency(other.getLatency());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.clients.ClientOuterClass.Client parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.clients.ClientOuterClass.Client) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 1;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object name_ = "";
      /**
       * <code>string name = 2;</code>
       */
      public java.lang.String getName() {
        java.lang.Object ref = name_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          name_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public com.google.protobuf.ByteString
          getNameBytes() {
        java.lang.Object ref = name_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          name_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        name_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder clearName() {
        
        name_ = getDefaultInstance().getName();
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        name_ = value;
        onChanged();
        return this;
      }

      private java.util.List<ubii.devices.DeviceOuterClass.Device> devices_ =
        java.util.Collections.emptyList();
      private void ensureDevicesIsMutable() {
        if (!((bitField0_ & 0x00000004) == 0x00000004)) {
          devices_ = new java.util.ArrayList<ubii.devices.DeviceOuterClass.Device>(devices_);
          bitField0_ |= 0x00000004;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder> devicesBuilder_;

      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public java.util.List<ubii.devices.DeviceOuterClass.Device> getDevicesList() {
        if (devicesBuilder_ == null) {
          return java.util.Collections.unmodifiableList(devices_);
        } else {
          return devicesBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public int getDevicesCount() {
        if (devicesBuilder_ == null) {
          return devices_.size();
        } else {
          return devicesBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public ubii.devices.DeviceOuterClass.Device getDevices(int index) {
        if (devicesBuilder_ == null) {
          return devices_.get(index);
        } else {
          return devicesBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder setDevices(
          int index, ubii.devices.DeviceOuterClass.Device value) {
        if (devicesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureDevicesIsMutable();
          devices_.set(index, value);
          onChanged();
        } else {
          devicesBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder setDevices(
          int index, ubii.devices.DeviceOuterClass.Device.Builder builderForValue) {
        if (devicesBuilder_ == null) {
          ensureDevicesIsMutable();
          devices_.set(index, builderForValue.build());
          onChanged();
        } else {
          devicesBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder addDevices(ubii.devices.DeviceOuterClass.Device value) {
        if (devicesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureDevicesIsMutable();
          devices_.add(value);
          onChanged();
        } else {
          devicesBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder addDevices(
          int index, ubii.devices.DeviceOuterClass.Device value) {
        if (devicesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureDevicesIsMutable();
          devices_.add(index, value);
          onChanged();
        } else {
          devicesBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder addDevices(
          ubii.devices.DeviceOuterClass.Device.Builder builderForValue) {
        if (devicesBuilder_ == null) {
          ensureDevicesIsMutable();
          devices_.add(builderForValue.build());
          onChanged();
        } else {
          devicesBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder addDevices(
          int index, ubii.devices.DeviceOuterClass.Device.Builder builderForValue) {
        if (devicesBuilder_ == null) {
          ensureDevicesIsMutable();
          devices_.add(index, builderForValue.build());
          onChanged();
        } else {
          devicesBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder addAllDevices(
          java.lang.Iterable<? extends ubii.devices.DeviceOuterClass.Device> values) {
        if (devicesBuilder_ == null) {
          ensureDevicesIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, devices_);
          onChanged();
        } else {
          devicesBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder clearDevices() {
        if (devicesBuilder_ == null) {
          devices_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
          onChanged();
        } else {
          devicesBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public Builder removeDevices(int index) {
        if (devicesBuilder_ == null) {
          ensureDevicesIsMutable();
          devices_.remove(index);
          onChanged();
        } else {
          devicesBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public ubii.devices.DeviceOuterClass.Device.Builder getDevicesBuilder(
          int index) {
        return getDevicesFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public ubii.devices.DeviceOuterClass.DeviceOrBuilder getDevicesOrBuilder(
          int index) {
        if (devicesBuilder_ == null) {
          return devices_.get(index);  } else {
          return devicesBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public java.util.List<? extends ubii.devices.DeviceOuterClass.DeviceOrBuilder> 
           getDevicesOrBuilderList() {
        if (devicesBuilder_ != null) {
          return devicesBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(devices_);
        }
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public ubii.devices.DeviceOuterClass.Device.Builder addDevicesBuilder() {
        return getDevicesFieldBuilder().addBuilder(
            ubii.devices.DeviceOuterClass.Device.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public ubii.devices.DeviceOuterClass.Device.Builder addDevicesBuilder(
          int index) {
        return getDevicesFieldBuilder().addBuilder(
            index, ubii.devices.DeviceOuterClass.Device.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.devices.Device devices = 3;</code>
       */
      public java.util.List<ubii.devices.DeviceOuterClass.Device.Builder> 
           getDevicesBuilderList() {
        return getDevicesFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder> 
          getDevicesFieldBuilder() {
        if (devicesBuilder_ == null) {
          devicesBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder>(
                  devices_,
                  ((bitField0_ & 0x00000004) == 0x00000004),
                  getParentForChildren(),
                  isClean());
          devices_ = null;
        }
        return devicesBuilder_;
      }

      private com.google.protobuf.LazyStringList tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureTagsIsMutable() {
        if (!((bitField0_ & 0x00000008) == 0x00000008)) {
          tags_ = new com.google.protobuf.LazyStringArrayList(tags_);
          bitField0_ |= 0x00000008;
         }
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getTagsList() {
        return tags_.getUnmodifiableView();
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public int getTagsCount() {
        return tags_.size();
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public java.lang.String getTags(int index) {
        return tags_.get(index);
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public com.google.protobuf.ByteString
          getTagsBytes(int index) {
        return tags_.getByteString(index);
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public Builder setTags(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureTagsIsMutable();
        tags_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public Builder addTags(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureTagsIsMutable();
        tags_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public Builder addAllTags(
          java.lang.Iterable<java.lang.String> values) {
        ensureTagsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, tags_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public Builder clearTags() {
        tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000008);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 4;</code>
       */
      public Builder addTagsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureTagsIsMutable();
        tags_.add(value);
        onChanged();
        return this;
      }

      private java.lang.Object description_ = "";
      /**
       * <code>string description = 5;</code>
       */
      public java.lang.String getDescription() {
        java.lang.Object ref = description_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          description_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string description = 5;</code>
       */
      public com.google.protobuf.ByteString
          getDescriptionBytes() {
        java.lang.Object ref = description_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          description_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string description = 5;</code>
       */
      public Builder setDescription(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        description_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string description = 5;</code>
       */
      public Builder clearDescription() {
        
        description_ = getDefaultInstance().getDescription();
        onChanged();
        return this;
      }
      /**
       * <code>string description = 5;</code>
       */
      public Builder setDescriptionBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        description_ = value;
        onChanged();
        return this;
      }

      private java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> processingModules_ =
        java.util.Collections.emptyList();
      private void ensureProcessingModulesIsMutable() {
        if (!((bitField0_ & 0x00000020) == 0x00000020)) {
          processingModules_ = new java.util.ArrayList<ubii.processing.ProcessingModuleOuterClass.ProcessingModule>(processingModules_);
          bitField0_ |= 0x00000020;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> processingModulesBuilder_;

      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> getProcessingModulesList() {
        if (processingModulesBuilder_ == null) {
          return java.util.Collections.unmodifiableList(processingModules_);
        } else {
          return processingModulesBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public int getProcessingModulesCount() {
        if (processingModulesBuilder_ == null) {
          return processingModules_.size();
        } else {
          return processingModulesBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index) {
        if (processingModulesBuilder_ == null) {
          return processingModules_.get(index);
        } else {
          return processingModulesBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder setProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.set(index, value);
          onChanged();
        } else {
          processingModulesBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder setProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.set(index, builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder addProcessingModules(ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.add(value);
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder addProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.add(index, value);
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder addProcessingModules(
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.add(builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder addProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.add(index, builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder addAllProcessingModules(
          java.lang.Iterable<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModule> values) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, processingModules_);
          onChanged();
        } else {
          processingModulesBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder clearProcessingModules() {
        if (processingModulesBuilder_ == null) {
          processingModules_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000020);
          onChanged();
        } else {
          processingModulesBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public Builder removeProcessingModules(int index) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.remove(index);
          onChanged();
        } else {
          processingModulesBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder getProcessingModulesBuilder(
          int index) {
        return getProcessingModulesFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
          int index) {
        if (processingModulesBuilder_ == null) {
          return processingModules_.get(index);  } else {
          return processingModulesBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
           getProcessingModulesOrBuilderList() {
        if (processingModulesBuilder_ != null) {
          return processingModulesBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(processingModules_);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder addProcessingModulesBuilder() {
        return getProcessingModulesFieldBuilder().addBuilder(
            ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder addProcessingModulesBuilder(
          int index) {
        return getProcessingModulesFieldBuilder().addBuilder(
            index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 6;</code>
       */
      public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder> 
           getProcessingModulesBuilderList() {
        return getProcessingModulesFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
          getProcessingModulesFieldBuilder() {
        if (processingModulesBuilder_ == null) {
          processingModulesBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder>(
                  processingModules_,
                  ((bitField0_ & 0x00000020) == 0x00000020),
                  getParentForChildren(),
                  isClean());
          processingModules_ = null;
        }
        return processingModulesBuilder_;
      }

      private boolean isDedicatedProcessingNode_ ;
      /**
       * <code>bool is_dedicated_processing_node = 7;</code>
       */
      public boolean getIsDedicatedProcessingNode() {
        return isDedicatedProcessingNode_;
      }
      /**
       * <code>bool is_dedicated_processing_node = 7;</code>
       */
      public Builder setIsDedicatedProcessingNode(boolean value) {
        
        isDedicatedProcessingNode_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>bool is_dedicated_processing_node = 7;</code>
       */
      public Builder clearIsDedicatedProcessingNode() {
        
        isDedicatedProcessingNode_ = false;
        onChanged();
        return this;
      }

      private java.lang.Object hostIp_ = "";
      /**
       * <code>string host_ip = 8;</code>
       */
      public java.lang.String getHostIp() {
        java.lang.Object ref = hostIp_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          hostIp_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string host_ip = 8;</code>
       */
      public com.google.protobuf.ByteString
          getHostIpBytes() {
        java.lang.Object ref = hostIp_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          hostIp_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string host_ip = 8;</code>
       */
      public Builder setHostIp(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        hostIp_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string host_ip = 8;</code>
       */
      public Builder clearHostIp() {
        
        hostIp_ = getDefaultInstance().getHostIp();
        onChanged();
        return this;
      }
      /**
       * <code>string host_ip = 8;</code>
       */
      public Builder setHostIpBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        hostIp_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object metadataJson_ = "";
      /**
       * <code>string metadata_json = 9;</code>
       */
      public java.lang.String getMetadataJson() {
        java.lang.Object ref = metadataJson_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          metadataJson_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string metadata_json = 9;</code>
       */
      public com.google.protobuf.ByteString
          getMetadataJsonBytes() {
        java.lang.Object ref = metadataJson_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          metadataJson_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string metadata_json = 9;</code>
       */
      public Builder setMetadataJson(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        metadataJson_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string metadata_json = 9;</code>
       */
      public Builder clearMetadataJson() {
        
        metadataJson_ = getDefaultInstance().getMetadataJson();
        onChanged();
        return this;
      }
      /**
       * <code>string metadata_json = 9;</code>
       */
      public Builder setMetadataJsonBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        metadataJson_ = value;
        onChanged();
        return this;
      }

      private int state_ = 0;
      /**
       * <code>.ubii.clients.Client.State state = 10;</code>
       */
      public int getStateValue() {
        return state_;
      }
      /**
       * <code>.ubii.clients.Client.State state = 10;</code>
       */
      public Builder setStateValue(int value) {
        state_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.clients.Client.State state = 10;</code>
       */
      public ubii.clients.ClientOuterClass.Client.State getState() {
        @SuppressWarnings("deprecation")
        ubii.clients.ClientOuterClass.Client.State result = ubii.clients.ClientOuterClass.Client.State.valueOf(state_);
        return result == null ? ubii.clients.ClientOuterClass.Client.State.UNRECOGNIZED : result;
      }
      /**
       * <code>.ubii.clients.Client.State state = 10;</code>
       */
      public Builder setState(ubii.clients.ClientOuterClass.Client.State value) {
        if (value == null) {
          throw new NullPointerException();
        }
        
        state_ = value.getNumber();
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.clients.Client.State state = 10;</code>
       */
      public Builder clearState() {
        
        state_ = 0;
        onChanged();
        return this;
      }

      private float latency_ ;
      /**
       * <code>float latency = 11;</code>
       */
      public float getLatency() {
        return latency_;
      }
      /**
       * <code>float latency = 11;</code>
       */
      public Builder setLatency(float value) {
        
        latency_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>float latency = 11;</code>
       */
      public Builder clearLatency() {
        
        latency_ = 0F;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.clients.Client)
    }

    // @@protoc_insertion_point(class_scope:ubii.clients.Client)
    private static final ubii.clients.ClientOuterClass.Client DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.clients.ClientOuterClass.Client();
    }

    public static ubii.clients.ClientOuterClass.Client getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Client>
        PARSER = new com.google.protobuf.AbstractParser<Client>() {
      @java.lang.Override
      public Client parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Client(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Client> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Client> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.clients.ClientOuterClass.Client getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface ClientListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.clients.ClientList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    java.util.List<ubii.clients.ClientOuterClass.Client> 
        getElementsList();
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    ubii.clients.ClientOuterClass.Client getElements(int index);
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    java.util.List<? extends ubii.clients.ClientOuterClass.ClientOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    ubii.clients.ClientOuterClass.ClientOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.clients.ClientList}
   */
  public  static final class ClientList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.clients.ClientList)
      ClientListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use ClientList.newBuilder() to construct.
    private ClientList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private ClientList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private ClientList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.clients.ClientOuterClass.Client>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.clients.ClientOuterClass.Client.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.clients.ClientOuterClass.internal_static_ubii_clients_ClientList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.clients.ClientOuterClass.internal_static_ubii_clients_ClientList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.clients.ClientOuterClass.ClientList.class, ubii.clients.ClientOuterClass.ClientList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.clients.ClientOuterClass.Client> elements_;
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    public java.util.List<ubii.clients.ClientOuterClass.Client> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    public java.util.List<? extends ubii.clients.ClientOuterClass.ClientOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    public ubii.clients.ClientOuterClass.Client getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.clients.Client elements = 1;</code>
     */
    public ubii.clients.ClientOuterClass.ClientOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.clients.ClientOuterClass.ClientList)) {
        return super.equals(obj);
      }
      ubii.clients.ClientOuterClass.ClientList other = (ubii.clients.ClientOuterClass.ClientList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.clients.ClientOuterClass.ClientList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.clients.ClientOuterClass.ClientList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.clients.ClientList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.clients.ClientList)
        ubii.clients.ClientOuterClass.ClientListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_ClientList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_ClientList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.clients.ClientOuterClass.ClientList.class, ubii.clients.ClientOuterClass.ClientList.Builder.class);
      }

      // Construct using ubii.clients.ClientOuterClass.ClientList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.clients.ClientOuterClass.internal_static_ubii_clients_ClientList_descriptor;
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.ClientList getDefaultInstanceForType() {
        return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.ClientList build() {
        ubii.clients.ClientOuterClass.ClientList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.clients.ClientOuterClass.ClientList buildPartial() {
        ubii.clients.ClientOuterClass.ClientList result = new ubii.clients.ClientOuterClass.ClientList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.clients.ClientOuterClass.ClientList) {
          return mergeFrom((ubii.clients.ClientOuterClass.ClientList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.clients.ClientOuterClass.ClientList other) {
        if (other == ubii.clients.ClientOuterClass.ClientList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.clients.ClientOuterClass.ClientList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.clients.ClientOuterClass.ClientList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.clients.ClientOuterClass.Client> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.clients.ClientOuterClass.Client>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public java.util.List<ubii.clients.ClientOuterClass.Client> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public ubii.clients.ClientOuterClass.Client getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.clients.ClientOuterClass.Client value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.clients.ClientOuterClass.Client.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder addElements(ubii.clients.ClientOuterClass.Client value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.clients.ClientOuterClass.Client value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder addElements(
          ubii.clients.ClientOuterClass.Client.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.clients.ClientOuterClass.Client.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.clients.ClientOuterClass.Client> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public ubii.clients.ClientOuterClass.Client.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public ubii.clients.ClientOuterClass.ClientOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public java.util.List<? extends ubii.clients.ClientOuterClass.ClientOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public ubii.clients.ClientOuterClass.Client.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.clients.ClientOuterClass.Client.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public ubii.clients.ClientOuterClass.Client.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.clients.ClientOuterClass.Client.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.clients.Client elements = 1;</code>
       */
      public java.util.List<ubii.clients.ClientOuterClass.Client.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.clients.ClientList)
    }

    // @@protoc_insertion_point(class_scope:ubii.clients.ClientList)
    private static final ubii.clients.ClientOuterClass.ClientList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.clients.ClientOuterClass.ClientList();
    }

    public static ubii.clients.ClientOuterClass.ClientList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<ClientList>
        PARSER = new com.google.protobuf.AbstractParser<ClientList>() {
      @java.lang.Override
      public ClientList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new ClientList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<ClientList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<ClientList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.clients.ClientOuterClass.ClientList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_clients_Client_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_clients_Client_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_clients_ClientList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_clients_ClientList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\032proto/clients/client.proto\022\014ubii.clien" +
      "ts\032\032proto/devices/device.proto\032\'proto/pr" +
      "ocessing/processingModule.proto\"\351\002\n\006Clie" +
      "nt\022\n\n\002id\030\001 \001(\t\022\014\n\004name\030\002 \001(\t\022%\n\007devices\030" +
      "\003 \003(\0132\024.ubii.devices.Device\022\014\n\004tags\030\004 \003(" +
      "\t\022\023\n\013description\030\005 \001(\t\022=\n\022processing_mod" +
      "ules\030\006 \003(\0132!.ubii.processing.ProcessingM" +
      "odule\022$\n\034is_dedicated_processing_node\030\007 " +
      "\001(\010\022\017\n\007host_ip\030\010 \001(\t\022\025\n\rmetadata_json\030\t " +
      "\001(\t\022)\n\005state\030\n \001(\0162\032.ubii.clients.Client" +
      ".State\022\017\n\007latency\030\013 \001(\002\"2\n\005State\022\n\n\006ACTI" +
      "VE\020\000\022\014\n\010INACTIVE\020\001\022\017\n\013UNAVAILABLE\020\002\"4\n\nC" +
      "lientList\022&\n\010elements\030\001 \003(\0132\024.ubii.clien" +
      "ts.Clientb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.devices.DeviceOuterClass.getDescriptor(),
          ubii.processing.ProcessingModuleOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_clients_Client_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_clients_Client_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_clients_Client_descriptor,
        new java.lang.String[] { "Id", "Name", "Devices", "Tags", "Description", "ProcessingModules", "IsDedicatedProcessingNode", "HostIp", "MetadataJson", "State", "Latency", });
    internal_static_ubii_clients_ClientList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_clients_ClientList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_clients_ClientList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.devices.DeviceOuterClass.getDescriptor();
    ubii.processing.ProcessingModuleOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
